Verified Commit 71279ade authored by Michael R. Crusoe's avatar Michael R. Crusoe 🏳️‍🌈
Browse files

Fix the already shipped tests and enable them as autopkgtests.

parent 1168fc9e
Loading
Loading
Loading
Loading
+7 −0
Original line number Diff line number Diff line
python-schema-salad (3.0.20181206233650-2) unstable; urgency=medium

  * Fix the already shipped tests and enable them as autopkgtests.
  * Run the same tests at compile time.

 -- Michael R. Crusoe <michael.crusoe@gmail.com>  Fri, 04 Jan 2019 06:45:22 -0800

python-schema-salad (3.0.20181206233650-1) unstable; urgency=medium

  * New upstream version
+2 −1
Original line number Diff line number Diff line
@@ -2,7 +2,6 @@ Source: python-schema-salad
Maintainer: Debian Med Packaging Team <debian-med-packaging@lists.alioth.debian.org>
Uploaders: Michael R. Crusoe <michael.crusoe@gmail.com>
Section: python
Testsuite: autopkgtest-pkg-python
Priority: optional
Build-Depends: debhelper (>= 11~),
               dh-python,
@@ -18,6 +17,8 @@ Build-Depends: debhelper (>= 11~),
               python3-cachecontrol,
               python3-lockfile,
               python3-typing-extensions,
	       python3-pytest-xdist,
	       python3-pytest-runner,
               help2man
Standards-Version: 4.3.0
Vcs-Browser: https://salsa.debian.org/med-team/python-schema-salad
+58 −0
Original line number Diff line number Diff line
@@ -285,3 +285,61 @@ Subject: Add proper "#!" header to all CWL files
-    out: [out]
\ No newline at end of file
+    out: [out]
--- schema-salad.orig/schema_salad/tests/test_print_oneline.py
+++ schema-salad/schema_salad/tests/test_print_oneline.py
@@ -46,7 +46,7 @@
             except RuntimeError as e:
                 msg = reformat_yaml_exception_message(strip_dup_lineno(six.text_type(e)))
                 msg = to_one_line_messages(msg)
-                self.assertTrue(msg.endswith(src+":10:1: could not find expected \':\'"))
+                self.assertTrue(msg.endswith(src+":11:1: could not find expected \':\'"))
                 print("\n", e)
                 raise
 
@@ -62,10 +62,9 @@
                                   six.text_type(get_data("tests/test_schema/"+src)), True)
             except ValidationException as e:
                 msgs = to_one_line_messages(str(e)).splitlines()
-                self.assertEqual(len(msgs), 3)
-                self.assertTrue(msgs[0].endswith(src+":9:1: the `outputs` field is not valid because"))
-                self.assertTrue(msgs[1].endswith(src+":13:5: missing required field `id`"))
-                self.assertTrue(msgs[2].endswith(src+":13:5: invalid field `aa`, expected one of: 'label', 'secondaryFiles', 'format', 'streamable', 'doc', 'id', 'outputBinding', 'type'"))
+                assert len(msgs) == 2, msgs
+                self.assertTrue(msgs[0].endswith(src+":14:5: missing required field `id`"))
+                self.assertTrue(msgs[1].endswith(src+":14:5: invalid field `aa`, expected one of: 'label', 'secondaryFiles', 'format', 'streamable', 'doc', 'id', 'outputBinding', 'type'"))
                 print("\n", e)
                 raise
 
@@ -88,9 +87,9 @@
                 self.assertEqual(len(msgs), 2)
                 print("\n", e)
                 assert msgs[0].endswith(
-                    src + ':8:1: checking field `outputs`')
+                    src + ':9:1: checking field `outputs`')
                 assert msgs[1].endswith(
                     src + ':13:5: Field `type` references unknown identifier '
                     '`Filea`, tried file://%s#Filea' % (fullpath))
                 raise
 
@@ -108,8 +107,8 @@
                 msg = reformat_yaml_exception_message(strip_dup_lineno(six.text_type(e)))
                 msgs = msg.splitlines()
                 self.assertEqual(len(msgs), 2)
-                self.assertTrue(msgs[0].endswith(src+":9:7: while scanning a simple key"))
-                self.assertTrue(msgs[1].endswith(src+":10:1:   could not find expected ':'"))
+                self.assertTrue(msgs[0].endswith(src+":10:7: while scanning a simple key"))
+                self.assertTrue(msgs[1].endswith(src+":11:1:   could not find expected ':'"))
                 print("\n", e)
                 raise
 
@@ -125,7 +124,7 @@
                                   six.text_type(get_data("tests/test_schema/"+src)), True)
             except RuntimeError as e:
                 msg = reformat_yaml_exception_message(strip_dup_lineno(six.text_type(e)))
-                self.assertTrue(msg.endswith(src+":1:1: expected <block end>, but found ':'")
-                                or msg.endswith(src+":1:1: expected <block end>, but found u':'"))
+                self.assertTrue(msg.endswith(src+":2:1: expected <block end>, but found ':'")
+                                or msg.endswith(src+":2:1: expected <block end>, but found u':'"))
                 print("\n", e)
                 raise
+10 −1
Original line number Diff line number Diff line
@@ -5,7 +5,7 @@ DH_VERBOSE := 1
include /usr/share/dpkg/pkg-info.mk

export PYBUILD_NAME=schema-salad
export PYBUILD_DISABLE=test
#export PYBUILD_DISABLE=test

%:
	dh $@ --with python3 --buildsystem=pybuild
@@ -32,6 +32,15 @@ override_dh_auto_build:
	sed -i 's/PYTHON/SCHEMA-SALAD-DOC/g' debian/schema-salad-doc.1
	find . -name "*.coverage" -delete

override_dh_auto_test:
ifeq (,$(filter nocheck,$(DEB_BUILD_OPTIONS)))
	dh_auto_install
	PYBUILD_SYSTEM=custom \
	PYBUILD_TEST_ARGS="cd {dir}; export PATH={destdir}/usr/bin:$$PATH ; \
	cd {build_dir}; export PYTHONPATH=$$(pwd); python3 -m pytest \
		-n auto --dist=loadfile --pyarg schema_salad" dh_auto_test
endif

override_dh_auto_install:
	dh_auto_install
	find debian -name LICENSE -delete

debian/tests/control

0 → 100644
+3 −0
@@ -88,9 +87,9 @@
                 assert msgs[1].endswith(
-                    src + ':13:5: Field `type` references unknown identifier '
+                    src + ':14:5: Field `type` references unknown identifier '
                     '`Filea`, tried file://%s#Filea' % (fullpath))
                 raise
Original line number Diff line number Diff line
Tests: run-tests
Depends: @, python3-pytest-xdist
Restrictions: allow-stderr
Loading